==> de.bsvrz.buv.plugin.dobj.source_4.0.0.201905071350.jar: de/bsvrz/buv/plugin/dobj/actions/ToggleOnlineAction.java <==
/*
 * Rahmenwerk-Plug-in "Darstellungsobjekte"
 * Copyright (C) 2018 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weissenfelser Strasse 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */
package de.bsvrz.buv.plugin.dobj.actions;

import org.eclipse.gef.EditPart;
import org.eclipse.gef.RootEditPart;
import org.eclipse.ui.IWorkbenchPart;

import de.bsvrz.buv.plugin.dobj.internal.DobjMessages;
import de.bsvrz.buv.plugin.dobj.requests.OnlineRequest;
import de.bsvrz.buv.plugin.dobj.util.DobjIcons;
import de.bsvrz.buv.plugin.dobj.util.DobjUtil;

/**
 * Action zum Umschalten zwischen Onlinemodus und Offlinemodus.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 *
 */
public class ToggleOnlineAction extends DobjWorkbenchPartAction {

	/**
	 * Initialisiert die Action.
	 *
	 * @param part
	 *            der Workbench Part für den die Action gilt.
	 */
	public ToggleOnlineAction(final IWorkbenchPart part) {
		super(part, AS_CHECK_BOX);

		setText(DobjMessages.ToggleOnline_Label);
		setImageDescriptor(DobjIcons.ActionToggleOnline.getImageDescriptor());
		setToolTipText(DobjMessages.ToggleOnline_Tooltip);

		setId(DobjActionFactory.TOGGLE_ONLINE.getCommandId());
		setActionDefinitionId(DobjActionFactory.TOGGLE_ONLINE.getCommandId());
	}

	/**
	 * Sendet an alle Edit Part des Viewer, einschließlich des Root Edit Parts,
	 * ein Request.
	 */
	@Override
	public void run() {
		final OnlineRequest request = new OnlineRequest(isChecked());
		final RootEditPart rootEditPart = getViewer().getRootEditPart();
		rootEditPart.performRequest(request);
		for (final EditPart editPart : DobjUtil.getAllChildren(rootEditPart)) {
			editPart.performRequest(request);
		}
	}

}

==> de.bsvrz.buv.plugin.dobj.source_4.5.0.202510170820.jar: de/bsvrz/buv/plugin/dobj/actions/ToggleOnlineAction.java <==
/*
 * Rahmenwerk-Plug-in "Darstellungsobjekte"
 * Copyright (C) 2023 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weissenfelser Strasse 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */
package de.bsvrz.buv.plugin.dobj.actions;

import org.eclipse.gef.EditPart;
import org.eclipse.gef.RootEditPart;
import org.eclipse.ui.IWorkbenchPart;

import de.bsvrz.buv.plugin.dobj.internal.DobjMessages;
import de.bsvrz.buv.plugin.dobj.requests.OnlineRequest;
import de.bsvrz.buv.plugin.dobj.util.DobjIcons;
import de.bsvrz.buv.plugin.dobj.util.DobjUtil;

/**
 * Action zum Umschalten zwischen Onlinemodus und Offlinemodus.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 *
 */
public class ToggleOnlineAction extends DobjWorkbenchPartAction {

	/**
	 * Initialisiert die Action.
	 *
	 * @param part
	 *            der Workbench Part für den die Action gilt.
	 */
	public ToggleOnlineAction(final IWorkbenchPart part) {
		super(part, AS_CHECK_BOX);

		setText(DobjMessages.toggleOnlineLabel);
		setImageDescriptor(DobjIcons.ActionToggleOnline.getImageDescriptor());
		setToolTipText(DobjMessages.toggleOnlineTooltip);

		setId(DobjActionFactory.TOGGLE_ONLINE.getCommandId());
		setActionDefinitionId(DobjActionFactory.TOGGLE_ONLINE.getCommandId());
	}

	/**
	 * Sendet an alle Edit Part des Viewer, einschließlich des Root Edit Parts,
	 * ein Request.
	 */
	@Override
	public void run() {
		final OnlineRequest request = new OnlineRequest(isChecked());
		final RootEditPart rootEditPart = getViewer().getRootEditPart();
		rootEditPart.performRequest(request);
		for (final EditPart editPart : DobjUtil.getAllChildren(rootEditPart)) {
			editPart.performRequest(request);
		}
	}

}
